package rs.fon.is.weka.classification;

import java.text.DecimalFormat;

import weka.classifiers.Evaluation;
import weka.classifiers.bayes.NaiveBayes;
import weka.classifiers.rules.ZeroR;
import weka.classifiers.trees.J48;
import weka.core.Instances;
import weka.core.converters.ConverterUtils.DataSource;

public class NaiveBayesClassificatorFromFile {

	private static String trainingDataFileName = "data/ToPlayOrNotToPlay.arff";
	private static String testDataFileName = "data/ToPlayOrNotToPlay-test.arff";

	public static void main(String[] args) throws Exception {

		// load training data
		Instances trainData = createDataset(trainingDataFileName);
		
		// Create the Naive Bayes Classifier
		NaiveBayes bayesClsf = new NaiveBayes();   
		bayesClsf.buildClassifier(trainData);
		
		// Create the Decision tree Classifier
		J48 dTreeClsf = new J48();
		dTreeClsf.buildClassifier(trainData);
		
		//baseline classifier
		ZeroR baselineClsf = new ZeroR();
		baselineClsf.buildClassifier(trainData);
		
		// load test data
		Instances testDataset = createDataset(testDataFileName);
		
		// evaluate all 3 classifiers on the test dataset
		Evaluation evalBaseline = new Evaluation(testDataset);
		evalBaseline.evaluateModel(baselineClsf, testDataset);
		
		Evaluation evalBayes = new Evaluation(testDataset);
		evalBayes.evaluateModel(bayesClsf, testDataset);
		
		Evaluation evalDTree = new Evaluation(testDataset);
		evalDTree.evaluateModel(dTreeClsf, testDataset);
		
		// Print performance measures for the 3 classifiers
		System.out.println("Classifier\tAccuracy\tPrecision\tRecall\tF measure");
		System.out.println("-----------------------------------------------------------------");
		printEvalMesaures("Baseline", evalBaseline, 0);
		printEvalMesaures("NaiveBayes", evalBayes, 0);
		printEvalMesaures("Dec. Tree", evalDTree, 0);
		
	}
	
	private static void printEvalMesaures(String clsfName, Evaluation eval, int positiveClass) {
		DecimalFormat formatter = new DecimalFormat();
		try {
			System.out.print(clsfName + "\t");
			double accuracy = eval.pctCorrect()/100;
			System.out.print(formatter.format(accuracy) + "\t\t");
			System.out.print(formatter.format(eval.precision(positiveClass)) + "\t\t");
			System.out.print(formatter.format(eval.recall(positiveClass)) + "\t");
			System.out.println(formatter.format(eval.fMeasure(positiveClass)));
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	private static Instances createDataset(String filePath) throws Exception {
		DataSource loader = new DataSource(filePath);
		Instances dataSet = loader.getDataSet();
		dataSet.setClassIndex(dataSet.numAttributes() - 1);
		return dataSet;
	}
	
	
}
