package rs.fon.is.weka.util;

import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.dom4j.Document;
import org.dom4j.DocumentHelper;
import org.dom4j.Element;
import org.dom4j.io.OutputFormat;
import org.dom4j.io.SAXReader;
import org.dom4j.io.XMLWriter;

import rs.fon.is.weka.domain.WeatherData;

public class RWXMLWeatherData {
	
	public static List<WeatherData> readWeatherDataFromFile(String filePath) throws Exception {
		
		ArrayList<WeatherData> weatherData = new ArrayList<>();
		
		SAXReader reader = new SAXReader();
		Document doc = reader.read(filePath);
		
		Element root = doc.getRootElement();
		List<Element> wDataElements = root.elements();
		for (int i = 0; i < wDataElements.size(); i++) {
			WeatherData dataItem = new WeatherData();
			dataItem.setOutlook( wDataElements.get(i).attributeValue("outlook") );
			dataItem.setTemperature( wDataElements.get(i).attributeValue("temperature") );
			dataItem.setHumidity( wDataElements.get(i).attributeValue("humidity") );
			dataItem.setWindy( wDataElements.get(i).attributeValue("windy") );
			dataItem.setPlay( wDataElements.get(i).attributeValue("play") );
			weatherData.add(dataItem);
		}
		
		return weatherData;
		
	}
	
	public static void writeWeatherDataToFile(String filePath, List<WeatherData> wDataList) throws IOException {
		
		Document doc = DocumentHelper.createDocument();
		Element root = doc.addElement("WeatherDataset");
		
		for (int i = 0; i < wDataList.size(); i++) {
			Element dataItem = root.addElement("Instance");
			dataItem.addAttribute("outlook", wDataList.get(i).getOutlook()).
					 addAttribute("temperature", wDataList.get(i).getTemperature()).
					 addAttribute("humidity", wDataList.get(i).getHumidity()).
					 addAttribute("windy", wDataList.get(i).getWindy()).
					 addAttribute("play", wDataList.get(i).getPlay());
		}
		
		OutputFormat format = OutputFormat.createPrettyPrint();
        XMLWriter writer = new XMLWriter(
            new FileWriter( filePath ), format);
        writer.write( doc );
        writer.close();
	}
	
	@SuppressWarnings("unused")
	private static List<WeatherData> createTrainWeatherData() {
		List<WeatherData> data = new ArrayList<>();
		
		data.add(new WeatherData("sunny", "hot", "high", "false", "no"));
		data.add(new WeatherData("sunny", "hot", "high", "true", "no"));
		data.add(new WeatherData("overcast", "hot", "high", "false", "yes"));
		data.add(new WeatherData("rainy", "mild", "high", "false", "yes"));
		data.add(new WeatherData("rainy", "cool", "normal", "false", "yes"));
		data.add(new WeatherData("rainy", "cool", "normal", "true", "no"));
		data.add(new WeatherData("overcast", "cool", "normal", "true", "yes"));
		data.add(new WeatherData("sunny", "mild", "high", "false", "no"));
		data.add(new WeatherData("sunny", "cool", "normal", "false", "yes"));
		data.add(new WeatherData("rainy", "mild", "normal", "false", "yes"));
		data.add(new WeatherData("sunny", "mild", "normal", "true", "yes"));
		data.add(new WeatherData("overcast", "mild", "high", "true", "yes"));
		data.add(new WeatherData("overcast", "hot", "normal", "false", "yes"));
		data.add(new WeatherData("rainy", "mild", "high", "true", "no"));
		
		return data;
	}
	
	@SuppressWarnings("unused")
	private static List<WeatherData> createTestWeatherData() {
		List<WeatherData> data = new ArrayList<>();
		
		data.add(new WeatherData("overcast","mild","normal","true","no"));
		data.add(new WeatherData("overcast","cool","high","true","yes"));
		data.add(new WeatherData("rainy","cool","high","true","no"));
		data.add(new WeatherData("rainy","mild","high","true","no"));
		data.add(new WeatherData("rainy","mild","high","true","no"));
		data.add(new WeatherData("sunny","hot","high","true","no"));
		data.add(new WeatherData("sunny","mild","normal","false","yes"));
		
		return data;
	
	}
	
//	public static void main(String[] args) {
//		try {
//			writeWeatherDataToFile("data/weatherTrainData.xml", createTrainWeatherData());
//			writeWeatherDataToFile("data/weatherTestData.xml", createTestWeatherData());
//		} catch (IOException e) {
//			// TODO Auto-generated catch block
//			e.printStackTrace();
//		}
//	}

}
